LabeledDimension — csdmpy 0.1.1 documentation

# LabeledDimension

## Generalized Class

Dimension

### Description

A labeled dimension is a qualitative dimension where the coordinates along the dimension are explicitly defined as labels. Let \(\mathbf{A}_k\) be an ordered set of unique labels along the \(k^{th}\) dimension, then the coordinates, \(\mathbf{X}_k\), along a labeled dimension are

\[\mathbf{X}_k = \mathbf{A}_k\]

### Attributes

Name | Type | Description
--- | --- | ---
labels | [String, String, … ] | An ordered array of labels along the dimension.

### Example

The following LabeledDimension object,

    {
        "type": "labeled",
        "labels": ["Cu", "Fe", "Si", "H", "Li"]
    }

will generate a dimension where coordinates \(\mathbf{X}_k\) are

    ["Cu", "Fe", "Si", "H", "Li"]